import { ColDef, ColumnState, GridOptions, RowDataTransaction, ServerSideTransaction } from '@ag-grid-community/core';
import { FieldMetadata } from '@genesislcap/foundation-comms';
import { Connect } from '@genesislcap/foundation-comms';
import { FoundationElement } from '@microsoft/fast-foundation';
import { GridPro } from '../grid-pro';
export declare class GenesisGridDatasourceElement extends FoundationElement {
    connect: Connect;
    deferredGridOptions: GridOptions;
    deferredColumnStates: ColumnState[];
    /**
     * Allows grid data updates to be processed via and external function before applying in grid
     */
    rowDataMapper: Function;
    criteria: string;
    fields: string;
    isSnapshot: boolean;
    maxRows: number;
    maxView: number;
    movingView: boolean;
    orderBy: string;
    resourceName: string;
    reverse: boolean;
    /**
     * Attribute to set an unique identifier for the row.
     *
     * Defaults to `ROW_REF` or `RECORD_ID` depending on the resource type.
     * @privateRemarks Attribute-only, not to be used as a property. Use `rowId` getter instead.
     */
    rowIdAttr: any;
    protected get rowId(): string;
    /**
     * Returns whether the `row-id` attribute is the default one, depending on the resource type.
     * @internal
     */
    protected get hasDefaultRowId(): boolean;
    protected get defaultRowIdByResourceType(): string;
    protected isRequestServer: boolean;
    protected get agGrid(): GridPro | null;
}
/**
 * The operation type for the {@link @genesislcap/grid-pro#GridProBaseDatasource.mapTransaction} method.
 * @internal
 */
export declare enum OperationType {
    Add = "add",
    Update = "update",
    Remove = "remove"
}
export declare class GridProBaseDatasource extends GenesisGridDatasourceElement {
    protected dataSubWasLoggedOff: boolean;
    rowData: Map<string, any>;
    protected agTransaction: RowDataTransaction | ServerSideTransaction;
    protected applyFuncName: string;
    protected applyAsyncFuncName: string;
    protected generateColumnDefsFromMetadata(fieldsMetadata: FieldMetadata[], getFilterParamsByFieldType: Function): ColDef[];
    protected handleStreamInserts(insertedRows: any[]): void;
    protected handleStreamDeletes(deletedRows: any[]): void;
    protected handleStreamUpdates(updatedRows: any[]): void;
    protected applyAllAgTransactions(): void;
    private flashAddedCells;
    private applyMappedAgTransaction;
    private setPreviouslySelectedCell;
    protected applyTransaction(agTransaction: RowDataTransaction): any;
    protected applyTransactionAsync(agTransaction: RowDataTransaction, callback?: (res: any) => void): void;
    /**
     * Maps the transaction data to the row data mapper function, if it exists.
     * @param transaction - The transaction data to be mapped.
     * @param operations - The operations to be mapped. Can be 'add', 'update' or 'remove'.
     * @returns The mapped transaction (if the row data mapper function exists), or the original transaction.
     */
    private mapTransaction;
}
export declare class StreamBaseDatasource {
    protected rowId: string;
    rowData: Map<string, any>;
}
//# sourceMappingURL=base.datasource.d.ts.map